/*
 *  Copyright 2008-2013 NVIDIA Corporation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

#pragma once

#include <thrust/detail/config.h>

#include <thrust/detail/type_traits.h>
#include <thrust/detail/type_traits/has_nested_type.h>

THRUST_NAMESPACE_BEGIN

namespace detail
{

__THRUST_DEFINE_HAS_NESTED_TYPE(is_metafunction_defined, type)

template <typename Metafunction>
struct enable_if_defined : thrust::detail::lazy_enable_if<is_metafunction_defined<Metafunction>::value, Metafunction>
{};

} // namespace detail

THRUST_NAMESPACE_END
